@@ -2,7 +2,7 @@
 
 # Laurent Montel <montel@kde.org> (2014)
 # KAction -> QAction
-# find -iname "*.cpp"|xargs kde-dev-scripts/kf5/convert-kaction.pl
+# find -iname "*.cpp" -o -iname "*.h"|xargs kde-dev-scripts/kf5/convert-kaction.pl
 
 use strict;
 use File::Basename;
@@ -11,6 +11,7 @@ use functionUtilkde;
 
 foreach my $file (@ARGV) {
 
+    my %headersToAdd = ();
     my $modified;
     open(my $FILE, "<", $file) or warn "We can't open file $file:$!\n";
     my @l = map {
@@ -19,14 +20,21 @@ foreach my $file (@ARGV) {
         s/\bKAction\s*\*/QAction \*/;
         s!KDE/KAction\b!QAction!;
         s!#include \<KAction\>!#include \<QAction\>!;
+        s!#include \<kaction.h\>!#include \<QAction\>!;
         s!class KAction;!class QAction;!;
         if (/setHelpText\b/) {
-           warn "QAction doesn't support setHelpText, just reimplement it in your code see kaction.cpp\n";
+           warn "$file: QAction doesn't support setHelpText, just reimplement it in your code see kaction.cpp\n";
         }
         if (/setShortcutConfigurable/) {
-           warn "QAction doesn't support directly setShortcutConfigurable, use KActionCollection::setShortcutsConfigurable(QAction *action, bool configurable)\n";
+           warn "$file: QAction doesn't support directly setShortcutConfigurable, use KActionCollection::setShortcutsConfigurable(QAction *action, bool configurable)\n";
         }
         s/\bKAction\b/QAction/g;
+
+        # While we're here...
+        if (s/KAuthorized::authorizeUrlAction/KUrlAuthorized::authorizeUrlAction/g) {
+            $headersToAdd{'kurlauthorized.h'} = 1;
+        }
+
         $modified ||= $orig ne $_;
         $_;
     } <$FILE>;
@@ -35,6 +43,9 @@ foreach my $file (@ARGV) {
         open (my $OUT, ">", $file);
         print $OUT @l;
         close ($OUT);
+        foreach my $include (keys %headersToAdd) {
+            functionUtilkde::addIncludeInFile($file, $include);
+        }
     }
 }
 
